@@ -1,7 +1,9 @@
 triang.list <- function (object) 
 {
     stopifnot(inherits(object,"deldir"))
-    tlist <- triMat(object)
+    io <- object$ind.orig
+    pt <- object$summary$pt.type
+    tlist <- prelimtlist(object)
     x <- object$summary[,"x"]
     y <- object$summary[,"y"]
     if("z" %in% colnames(object$summary)) {
@@ -42,14 +44,21 @@ triang.list <- function (object)
 		PACKAGE="deldir"
 	)
 	if(tmp$okay) {
+                tmp <- data.frame(ptNum=io[tlist[i,]],x=xtri[i,],y=ytri[i,])
+                if(length(pt)) tmp <- cbind(tmp[,1,drop=FALSE],
+                                            ptType=pt[tlist[i,]],tmp[,2:3])
+                if(haveZ) tmp <- cbind(tmp,z=ztri[i,])
 		K <- K+1
-		rslt[[K]] <- data.frame(ptNum=tlist[i,],x=xtri[i,],y=ytri[i,])
-                if(haveZ) {
-                    rslt[[K]] <- cbind(rslt[[K]],z=ztri[i,])
-                }
+                rslt[[K]] <- tmp
         }
     }
     attr(rslt,"rw") <- object$rw
     class(rslt) <- "triang.list"
     rslt
 }
+"[.triang.list" <- function(x,i,...){
+    y <- unclass(x)[i]
+    class(y) <- "triang.list"
+    attr(y,"rw") <- attr(x,"rw")
+y
+}
